@@ -60,17 +60,15 @@ bool X11Integration::eventFilter(QObject *watched, QEvent *event)
     if (event->type() == QEvent::PlatformSurface) {
         if (QWindow *w = qobject_cast<QWindow*>(watched)) {
             QPlatformSurfaceEvent *pe = static_cast<QPlatformSurfaceEvent*>(event);
-            if (!w->flags().testFlag(Qt::ForeignWindow)) {
-                if (pe->surfaceEventType() == QPlatformSurfaceEvent::SurfaceCreated) {
-                    if (qApp->property(s_schemePropertyName).isValid()) {
-                        installColorScheme(w);
-                    }
-                    const auto blurBehindProperty = w->property(s_blurBehindPropertyName.constData());
-                    if (blurBehindProperty.isValid()) {
-                        KWindowEffects::enableBlurBehind(w->winId(), blurBehindProperty.toBool());
-                    }
-                    installDesktopFileName(w);
+            if (pe->surfaceEventType() == QPlatformSurfaceEvent::SurfaceCreated) {
+                if (qApp->property(s_schemePropertyName).isValid()) {
+                    installColorScheme(w);
                 }
+                const auto blurBehindProperty = w->property(s_blurBehindPropertyName.constData());
+                if (blurBehindProperty.isValid()) {
+                    KWindowEffects::enableBlurBehind(w->winId(), blurBehindProperty.toBool());
+                }
+                installDesktopFileName(w);
             }
         }
     }
@@ -93,7 +91,7 @@ void X11Integration::installColorScheme(QWindow *w)
     if (atom == XCB_ATOM_NONE) {
         const QByteArray name = QByteArrayLiteral("_KDE_NET_WM_COLOR_SCHEME");
         const xcb_intern_atom_cookie_t cookie = xcb_intern_atom(c, false, name.length(), name.constData());
-        QScopedPointer<xcb_intern_atom_reply_t, QScopedPointerPodDeleter> reply(xcb_intern_atom_reply(c, cookie, Q_NULLPTR));
+        QScopedPointer<xcb_intern_atom_reply_t, QScopedPointerPodDeleter> reply(xcb_intern_atom_reply(c, cookie, nullptr));
         if (!reply.isNull()) {
             atom = reply->atom;
         } else {
@@ -131,7 +129,7 @@ void X11Integration::setWindowProperty(QWindow *window, const QByteArray &name,
     auto it = m_atoms.find(name);
     if (it == m_atoms.end()) {
         const xcb_intern_atom_cookie_t cookie = xcb_intern_atom(c, false, name.length(), name.constData());
-        QScopedPointer<xcb_intern_atom_reply_t, QScopedPointerPodDeleter> reply(xcb_intern_atom_reply(c, cookie, Q_NULLPTR));
+        QScopedPointer<xcb_intern_atom_reply_t, QScopedPointerPodDeleter> reply(xcb_intern_atom_reply(c, cookie, nullptr));
         if (!reply.isNull()) {
             atom = reply->atom;
             m_atoms[name] = atom;
